==> nextcloud-26.0.11p1.tgz: nextcloud/apps/theming/l10n/fa.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "نام داده شده بیش از حد بلند است",
    "The given web address is too long" : "نشانی وب داده شده بیش از حد بلند است",
    "The given web address is not a valid URL" : "نشانی وب داده شده معتبر نیست",
    "The given legal notice address is too long" : "نشانی توصیهٔ حقوقی داده شده بیش از حد بلند است",
    "The given legal notice address is not a valid URL" : "نشانی توصیهٔ حقوقی داده شده معتبر نیست",
    "The given privacy policy address is too long" : "نشانی سیاست محرمانگی داده شده بیش از حد بلند است",
    "The given privacy policy address is not a valid URL" : "نشانی سیاست محرمانگی داده شده معتبر نیست",
    "The given slogan is too long" : "شعار داده شده بیش از حد بلند است",
    "The given color is invalid" : "رنگ داده شده نامعتبر است",
    "Disable-user-theming should be true or false" : "مقدار Disable-user-theming باید true یا false باشد",
    "Saved" : "ذخیره شد",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پروندهٔ بارگذاری شده بیش‌تر از upload_max_filesize در php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پروندهٔ بارگذاری شده بیش‌تر از MAX_FILE_SIZE مشخّص شده در فرم HTML است",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شده بود",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشده",
    "Missing a temporary folder" : "یک شاخهٔ موقّتی گم شده",
    "Could not write file to disk" : "نتوانست پرونده را روی دیسک بنویسد",
    "A PHP extension stopped the file upload" : "یک افزونهٔ پی‌اچ‌پی بارگذاری پرونده را متوقّف کرد",
    "No file uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "هم‌اکنون در حال استفاده از یک زمینهٔ شخصی هستید. ممکن است تنظمیات کارهٔ زمینش به دستش پایکال شوند.",
    "Theming" : "زمینش",
    "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
    "Dark theme with high contrast mode" : "زمینهٔ تیره با حالت سایه‌روشن بالا",
    "Enable dark high contrast mode" : "به کار انداختن حالت سایه‌روشن تاریک",
    "Similar to the high contrast mode, but with dark colours." : "شبیه حالت سایه‌روشن بالا، ولی با رنگ‌های تیره",
    "Dark theme" : "زمینهٔ تیره",
    "Enable dark theme" : "به کار انداختن زمینهٔ تیره",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "زمینه‌ای تاریک برای آسایش چشمانتان با کاستن نوردهی و روشنایی کلّی.",
    "System default theme" : "زمینهٔ پیش‌گزیدهٔ سامانه",
    "Enable the system default" : "به کار انداختن پیش‌گزیدهٔ سامانه",
    "Using the default system appearance." : "در حال استفاده از ظاهر سامانهٔ پیش‌گزیده.",
    "Dyslexia font" : "قلم خوانش‌پریش",
    "Enable dyslexia font" : "به کار انداختن قلم خوانش‌پریش",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "اُپن‌دیسلکسیک قلمی آزاد است که برای کاهش برخی از خطاهای معمول در خواندن ناشی از خوانش‌پریشی طرّاحی شده.",
    "High contrast mode" : "حالت سایه‌روشن بالا",
    "Enable high contrast mode" : "به کار انداختن حالت سایه‌روشن بالا",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "حالتی با سایه‌روشن بالا برای آسایش ناوبریتان. کیفیت بصری کاهش خواهد یافت؛ ولی وضوح افزایش می‌باید.",
    "Light theme" : "زمینهٔ روشن",
    "Enable the default light theme" : "به کار انداختن زمینهٔ روشن پیش‌گزیده",
    "The default light appearance." : "ظاهر روشن پیش گزیده.",
    "Legal notice" : "توصیهٔ حقوقی",
    "Privacy policy" : "سیاست محرمانگی",
    "Adjust the Nextcloud theme" : "تنظیم زمینهٔ نکست‌کلود",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users.",
    "Advanced options" : "گزینه‌های پیش‌رفته",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "Name" : "نام",
    "Web link" : "پیوند وب",
    "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
    "Slogan" : "شعار",
    "Color" : "رنگ",
    "Logo" : "نشان",
    "Upload new logo" : "بارگذاری نشان جدید",
    "Background and login image" : "تصویر پس‌زمینه و ورود",
    "Upload new background and login image" : "بارگذاری تصویر پس‌زمینه و ورود جدید",
    "Legal notice link" : "پیوند توصیهٔ حقوقی",
    "Privacy policy link" : "پیوند سیاست محرمانگی",
    "Header logo" : "نشان سرایند",
    "Upload new header logo" : "بارگذاری نشان سرایند جدید",
    "Favicon" : "نقشک صفحه",
    "Upload new favicon" : "بارگذاری نقشک صفحهٔ جدید",
    "User settings" : "تنظمبات کاربری",
    "Disable user theming" : "از کار انداختن زمینش کاربری",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Background" : "پس‌زمینه",
    "Customization has been disabled by your administrator" : "شخصی‌سازی به دست مدیرتان از کار افتاده",
    "Set a custom background" : "تنظیم پس‌زمینه‌ای شخصی",
    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "از کار انداختن تمامی میان‌برهای صفحه‌کلید",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "دسترسی جهانی برای ما بسیار مهم است. ما از استانداردهای وب پیروی می‌کنیم و دقیت می‌کنیم تا همه چیز بدون موش‌واره و نرم‌افزارهای کمکی مانند صفحه‌خوان‌ها نیز قابل استفاده باشند. هدف ما این است که مطابق با دستورالعمل {guidelines}راهنماهای دسترس‌پذیری محتوا تحت وب{linkend} نسخه 2.1 در سطح AA، و حتی با زمینه کنتراست بالا در سطح AAA باشیم.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
    "Move up" : "Move up",
    "Move down" : "حرکت به پایین",
    "Custom background" : "Custom background",
    "Default background" : "Default background",
    "Change color" : "تغییر رنگ",
    "No background" : "No background",
    "Select a background from your files" : "Select a background from your files",
    "Theme selection is enforced" : "گزینش زمینه اجباری است",
    "Select a custom color" : "گزینش رنگی شخصی",
    "Reset to default" : "بازنشانی به پیش‌گزیده",
    "Upload" : "بارگذاری",
    "Remove background image" : "برداشتن تصویر پس‌زمینه"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-27.1.2.tgz: nextcloud/apps/theming/l10n/fa.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "نام داده شده بیش از حد بلند است",
    "The given web address is too long" : "نشانی وب داده شده بیش از حد بلند است",
    "The given web address is not a valid URL" : "نشانی وب داده شده معتبر نیست",
    "The given legal notice address is too long" : "نشانی توصیهٔ حقوقی داده شده بیش از حد بلند است",
    "The given legal notice address is not a valid URL" : "نشانی توصیهٔ حقوقی داده شده معتبر نیست",
    "The given privacy policy address is too long" : "نشانی سیاست محرمانگی داده شده بیش از حد بلند است",
    "The given privacy policy address is not a valid URL" : "نشانی سیاست محرمانگی داده شده معتبر نیست",
    "The given slogan is too long" : "شعار داده شده بیش از حد بلند است",
    "The given color is invalid" : "رنگ داده شده نامعتبر است",
    "Disable-user-theming should be true or false" : "مقدار Disable-user-theming باید true یا false باشد",
    "Saved" : "ذخیره شد",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پروندهٔ بارگذاری شده بیش‌تر از upload_max_filesize در php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پروندهٔ بارگذاری شده بیش‌تر از MAX_FILE_SIZE مشخّص شده در فرم HTML است",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شده بود",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشده",
    "Missing a temporary folder" : "یک شاخهٔ موقّتی گم شده",
    "Could not write file to disk" : "نتوانست پرونده را روی دیسک بنویسد",
    "A PHP extension stopped the file upload" : "یک افزونهٔ پی‌اچ‌پی بارگذاری پرونده را متوقّف کرد",
    "No file uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "هم‌اکنون در حال استفاده از یک زمینهٔ شخصی هستید. ممکن است تنظمیات کارهٔ زمینش به دستش پایکال شوند.",
    "Theming" : "زمینش",
    "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
    "Dark theme with high contrast mode" : "زمینهٔ تیره با حالت سایه‌روشن بالا",
    "Enable dark high contrast mode" : "به کار انداختن حالت سایه‌روشن تاریک",
    "Similar to the high contrast mode, but with dark colours." : "شبیه حالت سایه‌روشن بالا، ولی با رنگ‌های تیره",
    "Dark theme" : "زمینهٔ تیره",
    "Enable dark theme" : "به کار انداختن زمینهٔ تیره",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "زمینه‌ای تاریک برای آسایش چشمانتان با کاستن نوردهی و روشنایی کلّی.",
    "System default theme" : "زمینهٔ پیش‌گزیدهٔ سامانه",
    "Enable the system default" : "به کار انداختن پیش‌گزیدهٔ سامانه",
    "Using the default system appearance." : "در حال استفاده از ظاهر سامانهٔ پیش‌گزیده.",
    "Dyslexia font" : "قلم خوانش‌پریش",
    "Enable dyslexia font" : "به کار انداختن قلم خوانش‌پریش",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "اُپن‌دیسلکسیک قلمی آزاد است که برای کاهش برخی از خطاهای معمول در خواندن ناشی از خوانش‌پریشی طرّاحی شده.",
    "High contrast mode" : "حالت سایه‌روشن بالا",
    "Enable high contrast mode" : "به کار انداختن حالت سایه‌روشن بالا",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "حالتی با سایه‌روشن بالا برای آسایش ناوبریتان. کیفیت بصری کاهش خواهد یافت؛ ولی وضوح افزایش می‌باید.",
    "Light theme" : "زمینهٔ روشن",
    "Enable the default light theme" : "به کار انداختن زمینهٔ روشن پیش‌گزیده",
    "The default light appearance." : "ظاهر روشن پیش گزیده.",
    "Legal notice" : "توصیهٔ حقوقی",
    "Privacy policy" : "سیاست محرمانگی",
    "Adjust the Nextcloud theme" : "تنظیم زمینهٔ نکست‌کلود",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users.",
    "Advanced options" : "گزینه‌های پیش‌رفته",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "Name" : "نام",
    "Web link" : "پیوند وب",
    "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
    "Slogan" : "شعار",
    "Color" : "رنگ",
    "Logo" : "نشان",
    "Upload new logo" : "بارگذاری نشان جدید",
    "Background and login image" : "تصویر پس‌زمینه و ورود",
    "Upload new background and login image" : "بارگذاری تصویر پس‌زمینه و ورود جدید",
    "Legal notice link" : "پیوند توصیهٔ حقوقی",
    "Privacy policy link" : "پیوند سیاست محرمانگی",
    "Header logo" : "نشان سرایند",
    "Upload new header logo" : "بارگذاری نشان سرایند جدید",
    "Favicon" : "نقشک صفحه",
    "Upload new favicon" : "بارگذاری نقشک صفحهٔ جدید",
    "User settings" : "تنظمبات کاربری",
    "Disable user theming" : "از کار انداختن زمینش کاربری",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Background" : "پس‌زمینه",
    "Customization has been disabled by your administrator" : "شخصی‌سازی به دست مدیرتان از کار افتاده",
    "Set a custom background" : "تنظیم پس‌زمینه‌ای شخصی",
    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "از کار انداختن تمامی میان‌برهای صفحه‌کلید",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "دسترسی جهانی برای ما بسیار مهم است. ما از استانداردهای وب پیروی می‌کنیم و دقیت می‌کنیم تا همه چیز بدون موش‌واره و نرم‌افزارهای کمکی مانند صفحه‌خوان‌ها نیز قابل استفاده باشند. هدف ما این است که مطابق با دستورالعمل {guidelines}راهنماهای دسترس‌پذیری محتوا تحت وب{linkend} نسخه 2.1 در سطح AA، و حتی با زمینه کنتراست بالا در سطح AAA باشیم.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
    "Custom background" : "Custom background",
    "Default background" : "Default background",
    "Change color" : "تغییر رنگ",
    "No background" : "No background",
    "Select a background from your files" : "Select a background from your files",
    "Theme selection is enforced" : "گزینش زمینه اجباری است",
    "Select a custom color" : "گزینش رنگی شخصی",
    "Reset to default" : "بازنشانی به پیش‌گزیده",
    "Upload" : "بارگذاری",
    "Remove background image" : "برداشتن تصویر پس‌زمینه",
    "Loading preview…" : "بار کردن پیش‌نمایش…",
    "Admin" : "مدیر",
    "Error uploading the file" : "خطا در بارگذاری پرونده",
    "Name cannot be empty" : "نام نمی‌تواند خالی باشد",
    "Migrate and clean up admin theming images" : "Migrate and clean up admin theming images",
    "Failed to clean up the old admin theming images folder" : "Failed to clean up the old admin theming images folder",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Pick from Files" : "گزینش از پرونده‌ها",
    "Default image" : "تصویر پیش‌گزیده",
    "Custom color" : "رنگ سفارشی",
    "Plain background" : "پس‌زمینهٔ ساده",
    "Insert from {productName}" : "درج از {productName}",
    "Open documentation" : "گشودن مستندات",
    "https://…" : "https://…",
    "Upload new login background" : "بارگذاری تصویر ورود جدید",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color."
},
"nplurals=2; plural=(n > 1);");
